#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

from zope.interface import Interface

# import interfaces
from pyams_content.component.paragraph.interfaces import IParagraphContainer
from pyams_content.component.paragraph.portlet.interfaces import IParagraphContainerPortletSettings, \
    IParagraphNavigationPortletSettings
from pyams_content.features.renderer.interfaces import ISharedContentRenderer
from pyams_default_theme import _
from pyams_portal.interfaces import IPortalContext, IPortletRenderer
# import packages
from pyams_portal.portlet import PortletRenderer
from pyams_skin.layer import IPyAMSLayer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config


@adapter_config(context=(IPortalContext, IPyAMSLayer, Interface, IParagraphContainerPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/content.pt', layer=IPyAMSLayer)
class ParagraphContainerPortletRenderer(PortletRenderer):
    """Paragraph container default portlet renderer"""

    label = _("Default paragraphs renderer")

    renderers = ()

    def update(self):
        super(ParagraphContainerPortletRenderer, self).update()
        settings = self.settings
        registry = self.request.registry
        container = IParagraphContainer(self.context, None)
        if container is not None:
            paragraphs = container.get_visible_paragraphs(settings.paragraphs, settings.anchors_only,
                                                          settings.factories)
            renderers = [paragraph.get_renderer(self.request) for paragraph in paragraphs]
        else:
            renderers = [adapter for name, adapter in sorted(registry.getAdapters((self.context, self.request),
                                                                                  ISharedContentRenderer),
                                                             key=lambda x: x[1].weight)]
        self.renderers = list(filter(lambda x: x is not None, renderers))
        [renderer.update() for renderer in self.renderers]


@adapter_config(context=(IPortalContext, IPyAMSLayer, Interface, IParagraphNavigationPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/navigation.pt', layer=IPyAMSLayer)
class ParagraphNavigationPortletRenderer(PortletRenderer):
    """Paragraphs navigation default portlet renderer"""

    label = _("Default paragraphs navigation")

    paragraphs = ()

    def update(self):
        super(ParagraphNavigationPortletRenderer, self).update()
        settings = self.settings
        container = IParagraphContainer(self.context, None)
        if container is not None:
            self.paragraphs = container.get_visible_paragraphs(settings.paragraphs, settings.anchors_only,
                                                               settings.factories)
